@@ -19,7 +19,7 @@
  */
 
 
-/* $Id: mhash.c,v 1.4 2000/04/11 12:20:14 nmav Exp $ */
+/* $Id: mhash.c,v 1.8 2000/05/10 05:46:07 nmav Exp $ */
 
 #include <stdlib.h>
 
@@ -58,6 +58,7 @@ static mhash_hash_entry algorithms[] = {
 	MHASH_ENTRY(MHASH_HAVAL128, 16, 128),
 	MHASH_ENTRY(MHASH_HAVAL160, 20, 128),
 	MHASH_ENTRY(MHASH_HAVAL192, 24, 128),
+	MHASH_ENTRY(MHASH_HAVAL224, 28, 128),
 	MHASH_ENTRY(MHASH_RIPEMD160, 20, 64),
 	MHASH_ENTRY(MHASH_TIGER, 192 >> 3, 64),
 	MHASH_ENTRY(MHASH_GOST, 32, 0),
@@ -106,6 +107,8 @@ MHASH mhash_init_int(const hashid type)
 
 	ret = malloc(sizeof(MHASH_INSTANCE));
 	ret->algorithm_given = type;
+	ret->hmac_key = NULL;
+	ret->state = NULL;
 
 	switch (type) {
 	case MHASH_CRC32:
@@ -125,6 +128,10 @@ MHASH mhash_init_int(const hashid type)
 		ret->state = malloc(sizeof(havalContext));
 		havalInit( (void *) ret->state, 3, 256);
 		break;
+	case MHASH_HAVAL224:
+		ret->state = malloc(sizeof(havalContext));
+		havalInit( (void *) ret->state, 3, 224);
+		break;
 	case MHASH_HAVAL192:
 		ret->state = malloc(sizeof(havalContext));
 		havalInit( (void *) ret->state, 3, 192);
@@ -196,6 +203,7 @@ int mhash(MHASH thread, const void *plaintext, size_t size)
 			   size);
 		break;
 	case MHASH_HAVAL256:
+	case MHASH_HAVAL224:
 	case MHASH_HAVAL192:
 	case MHASH_HAVAL160:
 	case MHASH_HAVAL128:
@@ -240,6 +248,7 @@ void *mhash_end(MHASH thread)
 		rtmp = digest;
 		break;
 	case MHASH_HAVAL256:
+	case MHASH_HAVAL224:
 	case MHASH_HAVAL192:
 	case MHASH_HAVAL160:
 	case MHASH_HAVAL128:
@@ -267,7 +276,9 @@ void *mhash_end(MHASH thread)
 		break;
 	}
 
-	free(thread->state);
+	if (NULL != thread->state) {
+		free(thread->state);
+	}
 	free(thread);
 
 	return rtmp;
@@ -341,6 +352,7 @@ void *mhash_hmac_end(MHASH thread)
 		return_val = digest;
 		break;
 	case MHASH_HAVAL256:
+	case MHASH_HAVAL224:
 	case MHASH_HAVAL192:
 	case MHASH_HAVAL160:
 	case MHASH_HAVAL128:
@@ -370,7 +382,12 @@ void *mhash_hmac_end(MHASH thread)
 	mhash(tmptd, return_val,
 	      mhash_get_block_size(thread->algorithm_given));
 
+	if (NULL != return_val) {
+		free(return_val);
+	}
+	
 	free(thread->state);
+	free(opad);
 	mhash_bzero( thread->hmac_key, thread->hmac_key_size);
 	free(thread->hmac_key);
 	free(thread);
@@ -417,7 +434,6 @@ MHASH mhash_hmac_init(const hashid type, void *key, int keysize, int block)
 				    mhash_get_block_size(type);
 				ret->hmac_key = mhash_end(tmptd);
 			} else {
-//				ret->hmac_key_size = keysize;
 				ret->hmac_key = calloc(1, ret->hmac_block);
 				memmove(ret->hmac_key, key, keysize);
 				ret->hmac_key_size = ret->hmac_block;
@@ -433,6 +449,8 @@ MHASH mhash_hmac_init(const hashid type, void *key, int keysize, int block)
 			}
 
 			mhash(ret, ipad, ret->hmac_block);
+			
+			free(ipad);
 		}
 
 
